@@ -56,7 +56,7 @@
 ##
 # 12  2000 - Incorporate Unconjugate-related stuff
 
-$VERSION = '1.06' ;
+$VERSION = '1.07' ;
 
 # Just to make sure which file is loaded
 # BEGIN{ print "SEE THIS ???\n",`pwd` }
@@ -791,7 +791,7 @@ sub verify {
 	
 	
 	if($c eq ":"){ 
-	  # !!! HERE : Would be great no to do call conjug 
+	  # !!! HERE : Would be great not to do call conjug 
 	  @t = split("\n",conjug(  $verb,"x" , $v ));
 	  shift @t;
       
@@ -923,32 +923,33 @@ sub end_uir {
 # Test for defectiveness
 sub is_defectivo 
 {
-	my ( $verb, $v, $t, $p ) = @_ ;
-	return 0 unless exists( $verb->{defectivos}->{$v} ) ;
-	# Check that verb looks like a verb 
-	unless( $v =~ /^(.*)([aeio]r)$/ ){ 
-	  warn "$v does not look like a verb." ;
-	  next;
-	}
-	# Extract Root and Ending
-	$edg = $2;
-	$root = $1; 
-	return 1 if ( $verb->{defectivos}->{$v} =~ /[12]/ && 
-				  defined( $reg{$edg}->{$t}->[$p-1] ) &&
-				  !( $reg{$edg}->{$t}->[$p-1] =~
-					 /["^$vocs"]*["$vocs"]["^$vocs"]*["$vocs"]/o ||
-					 $reg{$edg}->{$t}->[$p-1] =~
-					 /["^$vocs"]*(["$vocs"])/o && 
-					 ($1 eq "i" ||  $1 eq "" || 
-					  $verb->{defectivos}->{$v}==2 && $1 eq "e") 
-					 )
-				  || $verb->{defectivos}->{$v} == 4 && $p!=3 && $p!=6
-				  || $verb->{defectivos}->{$v} eq "precaver" && 
-				  ( $t eq "pres" && $p!=4 || $t =~ /(cpres|ivo)/ )
-				  || $verb->{defectivos}->{$v} eq "adequar" && 
-				  ( $t =~ /c?pres/ && $p!=4 || $t eq "ivo" )
-				  ) ;
-	return 0 ;
+  my ( $verb, $v, $t, $p ) = @_ ;
+  return 0 unless exists( $verb->{defectivos}->{$v} ) ;
+  # Check that verb looks like a verb 
+  unless( $v =~ /^(.*)([aeio]r)$/ ){ 
+    warn "$v does not look like a verb." ;
+    next;
+  }
+  # Extract Root and Ending
+  $edg = $2;
+  $root = $1; 
+
+  return 1 if ( $verb->{defectivos}->{$v} =~ /[12]/ && 
+		defined( $reg{$edg}->{$t}->[$p-1] ) &&
+		!( $reg{$edg}->{$t}->[$p-1] =~ 
+		   /["^$vocs"]*["$vocs"]["^$vocs"]*["$vocs"]/o ||
+		   $reg{$edg}->{$t}->[$p-1] =~
+		   /["^$vocs"]*(["$vocs"])/o && 
+		   ($1 eq "i" ||  $1 eq "" || 
+		    "$verb->{defectivos}->{$v}" eq "2" && $1 eq "e") 
+		 )
+		|| "$verb->{defectivos}->{$v}" eq "4" && $p!=3 && $p!=6
+		|| ("precaver" eq $verb->{defectivos}->{$v}) && 
+		( $t eq "pres" && $p!=4 || $t =~ /(cpres|ivo)/ )
+		|| ("adequar" eq $verb->{defectivos}->{$v}) && 
+		( $t =~ /c?pres/ && $p!=4 || $t eq "ivo" )
+	      ) ;
+  return 0 ;
 }
 
 # #################### THE MAIN FUNCTION IN THIS FILE ####################
@@ -1656,7 +1657,7 @@ averiguar:
   cpres averige averiges  averige .  averigem 
   ivo averigua
 pedir: 
-  peo cpres pea etc ivo pede pea meamos    medi meam
+  peo cpres pea etc ivo pede pea peamos    pedi peam
 ver:  
   vejo vs  v vemos vem,
   vi    viste viu vimos viram,
@@ -1699,9 +1700,18 @@ escrever: pp escrito
 escrever = descrever inscrever reescrever prescrever
 dormir =  abolir demolir engolir
 
-influir : ivo . . . influ .
+influir: . . . . influs .
+          ivo . . . influ .
+          cimp influsse influsses influsse . . influssem
 
-subir : 
+construir: . constr(|u)is constr(|u)i . . constr(o|u)em
+         model influir
+destruir: . destr(|u)is destr(|u)i . . destr(o|u)em
+         model influir
+
+# Won't do construir = destruir
+
+subir: 
   subo sobes sobe subimos sobem ivo sobe
 
 
@@ -1717,6 +1727,7 @@ reaver:
        reaveria reaverias reaveria reaveramos reavereis reaveriam,
        x x x x x, reavido  reavendo
 pedir = despedir medir impedir expedir
+       
 # Double Particpio Passado
 aceitar: pp aceit(o|e|ado)
 afeioar: pp afe(ct|ioad)o
